==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/General/rgscan/translations/rgscan_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he_IL">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="29"/>
        <source>Write track gain/peak</source>
        <translation>רשום הישג/שיא רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="56"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="61"/>
        <source>Progress</source>
        <translation>התקדמות</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="66"/>
        <source>Track Gain</source>
        <translation>הישג רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="71"/>
        <source>Album Gain</source>
        <translation>הישג אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="76"/>
        <source>Track Peak</source>
        <translation>שיא רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="81"/>
        <source>Album Peak</source>
        <translation>שיא אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="89"/>
        <source>Calculate</source>
        <translation>חשב</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="96"/>
        <source>Write Tags</source>
        <translation>רשום תגיות</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="103"/>
        <source>Write album gain/peak</source>
        <translation>רשום הישג/שיא אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="114"/>
        <location filename="../rgscandialog.cpp" line="212"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="136"/>
        <location filename="../rgscandialog.cpp" line="207"/>
        <source>%1 dB</source>
        <translation>%1 דציבלים</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>תוספת סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>אודות תוספת סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>תוספת סורק ReplayGain עבור Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>תוספת זו סורקת קבצי שמע ונותנת מידע עבור נורצליזציה של עוצמת שמע</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>מבוססת על קוד מקור מאת:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qmmp-0.8.4.tar.bz2: qmmp-0.8.4/src/plugins/General/rgscan/translations/rgscan_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>RGScanDialog</name>
    <message>
        <location filename="../rgscandialog.ui" line="14"/>
        <source>ReplayGain Scanner</source>
        <translation>סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="29"/>
        <source>Write track gain/peak</source>
        <translation>רשום הישג/שיא רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="56"/>
        <source>Title</source>
        <translation>כותרת</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="61"/>
        <source>Progress</source>
        <translation>התקדמות</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="66"/>
        <source>Track Gain</source>
        <translation>הישג רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="71"/>
        <source>Album Gain</source>
        <translation>הישג אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="76"/>
        <source>Track Peak</source>
        <translation>שיא רצועה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="81"/>
        <source>Album Peak</source>
        <translation>שיא אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="89"/>
        <source>Calculate</source>
        <translation>חשב</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="96"/>
        <source>Write Tags</source>
        <translation>רשום תגיות</translation>
    </message>
    <message>
        <location filename="../rgscandialog.ui" line="103"/>
        <source>Write album gain/peak</source>
        <translation>רשום הישג/שיא אלבום</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="114"/>
        <location filename="../rgscandialog.cpp" line="212"/>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
    <message>
        <location filename="../rgscandialog.cpp" line="136"/>
        <location filename="../rgscandialog.cpp" line="207"/>
        <source>%1 dB</source>
        <translation>%1 דציבלים</translation>
    </message>
</context>
<context>
    <name>RGScanFactory</name>
    <message>
        <location filename="../rgscanfactory.cpp" line="28"/>
        <source>ReplayGain Scanner Plugin</source>
        <translation>תוספת סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="49"/>
        <source>About ReplayGain Scanner Plugin</source>
        <translation>אודות תוספת סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="50"/>
        <source>ReplayGain Scanner Plugin for Qmmp</source>
        <translation>תוספת סורק ReplayGain עבור Qmmp</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="51"/>
        <source>This plugin scans audio files and gives information for volume normalization</source>
        <translation>תוספת זו סורקת קבצי שמע ונותנת מידע עבור נורצליזציה של עוצמת שמע</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חוברה על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="53"/>
        <source>Based on source code by:</source>
        <translation>מבוססת על קוד מקור מאת:</translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="54"/>
        <source>David Robinson &lt;David@Robinson.org&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="55"/>
        <source>Glen Sawyer &lt;mp3gain@hotmail.com&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../rgscanfactory.cpp" line="56"/>
        <source>Frank Klemm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RGScanHelper</name>
    <message>
        <location filename="../rgscanhelper.cpp" line="32"/>
        <source>ReplayGain Scanner</source>
        <translation>סורק ReplayGain</translation>
    </message>
    <message>
        <location filename="../rgscanhelper.cpp" line="33"/>
        <source>Meta+R</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
